==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_home.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['home']['name']="Accueil";
$lang['home']['comment']="%s derniers commentaires";
$lang['home']['comment_to_moderate']="%s commentaire(s) en attente de validation";
$lang['home']['workshop_pending_users']="groupes de travail : %s utilisateur(s) en attente";
$lang['home']['project']="Projets arrivant à échéance prochainement";
$lang['home']['yp']="organisation(s) actuellement en préinscription";
$lang['home']['dashboard']="indicateur(s) à mettre à jour";
$lang['home']['user']="utilisateur(s) inscrit(s) depuis votre dernière connexion";
$lang['home']['news']="3 dernières actualités";
$lang['home']['publi']="dernières publications effectuées";
$lang['home']['report']="dernier rapport publié";
$lang['home']['accueil']="Bienvenue sur l'interface d'administration Linea 21, chaque module est accessible selon vos droits fixés par l'administrateur. Lors de la gestion des modules d'administration, pour toute question ou remarque, vous pouvez directement contacter le support en ligne de l'application à cette adresse ";

$lang['home']['resume']="Tâches d'administration Linea 21";
$lang['home']['noresult']="Actuellement, aucune donnée n'a été publiée pour ce module";
$lang['home']['noupdate']="Actuellement, aucune donnée ne doit être mise à jour pour ce module";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Pour accéder à un module de gestion, cliquez sur son nom dans le menu gauche de l'application";
$lang['home']['help_list2']="Vous pouvez réaliser une recherche goblale à tout moment en utilisant le champ de saisie nommé \"recherche\"";
$lang['home']['help_list3']="Pour effectuer une recherche par module, cliquez sur recherche dans la barre de rubrique";
$lang['home']['help_list4']="la rubrique d'aide est spécifique à chaque module de gestion, n'hésitez pas à la consulter !";


?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/fr/lang_home.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Accueil";
$lang['home']['comment']="%s derniers commentaires";
$lang['home']['comment_to_moderate']="%s commentaire(s) en attente de validation";
$lang['home']['workshop_pending_users']="groupes de travail : %s utilisateur(s) en attente";
$lang['home']['project']="Projets arrivant à échéance prochainement";
$lang['home']['latest_connected_users']="%s utilisateurs connectés les 15 dernières minutes";
$lang['home']['yp']="organisation(s) actuellement en préinscription";
$lang['home']['dashboard']="indicateur(s) à mettre à jour";
$lang['home']['user']="utilisateur(s) inscrit(s) depuis votre dernière connexion";
$lang['home']['news']="3 dernières actualités";
$lang['home']['publi']="dernières publications effectuées";
$lang['home']['report']="dernier rapport publié";
$lang['home']['accueil']="Bienvenue sur l'interface d'administration de Linea21 !";

$lang['home']['noresult']="Aucune donnée";
$lang['home']['noupdate']="Aucune donnée ne doit être mise à jour";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Pour accéder à un module de gestion, cliquez sur son nom dans le menu gauche de l'application";
$lang['home']['help_list2']="Vous pouvez réaliser une recherche goblale à tout moment en utilisant le champ de saisie nommé \"recherche\"";
$lang['home']['help_list3']="Pour effectuer une recherche par module, cliquez sur recherche dans la barre de rubrique";
$lang['home']['help_list4']="la rubrique d'aide est spécifique à chaque module de gestion, n'hésitez pas à la consulter !";


?>
